==> mozc_1.11.1522.102.orig.tar.bz2: mozc-1.11.1522.102/base/text_normalizer.h <==
// Copyright 2010-2013, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// static class for nomalizing session output
// Class functions to be used for output by the Session class.

#ifndef MOZC_BASE_TEXT_NORMALIZER_H_
#define MOZC_BASE_TEXT_NORMALIZER_H_

#include <string>
#include "base/base.h"
#include "base/string_piece.h"

namespace mozc {

class TextNormalizer {
 public:
  static void NormalizePreeditText(StringPiece input, string *output);
  static void NormalizeTransliterationText(StringPiece input, string *output);
  static void NormalizeConversionText(StringPiece input, string *output);
  static void NormalizeCandidateText(StringPiece input, string *output);

 private:
  TextNormalizer();
  ~TextNormalizer();
  DISALLOW_COPY_AND_ASSIGN(TextNormalizer);
};

}  // namespace mozc

#endif  // MOZC_BASE_TEXT_NORMALIZER_H_

==> mozc_1.12.1599.102.orig.tar.bz2: mozc-1.12.1599.102/base/text_normalizer.h <==
// Copyright 2010-2013, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// static class for nomalizing session output
// Class functions to be used for output by the Session class.

#ifndef MOZC_BASE_TEXT_NORMALIZER_H_
#define MOZC_BASE_TEXT_NORMALIZER_H_

#include <string>
#include "base/port.h"
#include "base/string_piece.h"

namespace mozc {

class TextNormalizer {
 public:
  static void NormalizePreeditText(StringPiece input, string *output);
  static void NormalizeTransliterationText(StringPiece input, string *output);
  static void NormalizeConversionText(StringPiece input, string *output);
  static void NormalizeCandidateText(StringPiece input, string *output);

 private:
  DISALLOW_IMPLICIT_CONSTRUCTORS(TextNormalizer);
};

}  // namespace mozc

#endif  // MOZC_BASE_TEXT_NORMALIZER_H_
